@@ -8,7 +8,7 @@
 #'   \url{https://stat.ethz.ch/pipermail/r-help/2005-September/079872.html}
 #' @return The AUC of the predicted Elo probabilities and the actual win results.
 #' @seealso \code{pROC::\link[pROC]{auc}}, \code{\link{elo.run}}.
-#' @name elo.auc
+#' @name auc.elo
 NULL
 #> NULL
 
@@ -22,7 +22,7 @@ get_auc <- function(wins, probs)
   (sum(rank(c(x.won, x.lost))[1:n.won]) - n.won*(n.won + 1)/2)/(n.won * length(x.lost))
 }
 
-#' @rdname elo.auc
+#' @rdname auc.elo
 #' @export
 auc.elo.run <- function(object, ...)
 {
@@ -31,14 +31,14 @@ auc.elo.run <- function(object, ...)
   get_auc(wins, probs)
 }
 
-#' @rdname elo.auc
+#' @rdname auc.elo
 #' @export
 auc.elo.glm <- function(object, ...)
 {
   get_auc(object$y, object$fitted.values)
 }
 
-#' @rdname elo.auc
+#' @rdname auc.elo
 #' @export
 auc.elo.running <- function(object, running = TRUE, ...)
 {
@@ -46,11 +46,14 @@ auc.elo.running <- function(object, running = TRUE, ...)
   get_auc(object$y, object$running.values)
 }
 
-#' @rdname elo.auc
+#' @rdname auc.elo
 #' @export
 auc.elo.markovchain <- auc.elo.glm
 
-#' @rdname elo.auc
+#' @rdname auc.elo
 #' @export
 auc.elo.winpct <- auc.elo.glm
 
+#' @rdname auc.elo
+#' @export
+auc.elo.colley <- auc.elo.glm
